<?php
/**
 * Backward compatibility functionality
 *
 * Prevents this theme from running on WordPress versions prior to 5, since this theme is not meant to be backward compatible beyond that and relies on many newer functions and markup changes introduced in 5. Although this theme can run with at least WordPress 4.7, block styles need at least version 5.0.
 *
 * @package Empt_Lite
 */

/**
 * Prevent switching to Empt on old versions of WordPress.
 * Switches to the default theme.
 */
function empt_lite_switch_theme() {
	switch_theme( WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'empt_lite_upgrade_notice' );
}
add_action( 'after_switch_theme', 'empt_lite_switch_theme' );

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * Empt on WordPress versions prior to 5.
 *
 * @global string $wp_version WordPress version.
 */
function empt_lite_upgrade_notice() {
	$message = sprintf( __( 'Empt Lite requires (preferably) at least WordPress version 5. You are running version %s. Please upgrade and try again.', 'empt-lite' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 5.
 * @global string $wp_version WordPress version.
 */
function empt_lite_customize() {
	wp_die(
		sprintf(
			__( 'Empt Lite requires (preferably) at least WordPress version 5. You are running version %s. Please upgrade and try again.', 'empt-lite' ),
			$GLOBALS['wp_version']
		),
		'',
		array(
			'back_link' => true,
		)
	);
}
add_action( 'load-customize.php', 'empt_lite_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 5.
 * @global string $wp_version WordPress version.
 */
function empt_lite_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'Empt Lite requires (preferably) at least WordPress version 5. You are running version %s. Please upgrade and try again.', 'empt-lite' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'empt_lite_preview' );
