<?php
/**
 * Theme Customizer
 * @package Empt_Lite
 */
function empt_lite_customize_register( $wp_customize ) {
	
    /** Add postMessage support for site title and description */
    $wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
    $wp_customize->get_setting( 'background_color' )->transport = 'refresh';
    $wp_customize->get_setting( 'background_image' )->transport = 'refresh';
	
    if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '#site-title a',
			'render_callback' => 'empt_lite_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '#site-description',
			'render_callback' => 'empt_lite_customize_partial_blogdescription',
		) );
	}

	// Show site title
	$wp_customize->add_setting( 'empt_lite_hide_site_title',	array(
		'default' => false,
		'transport'  => 'postMessage',
		'sanitize_callback' => 'empt_lite_sanitize_checkbox',
	) );  
	
	$wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_hide_site_title', array(	
		'label'    => esc_html__( 'Hide the Site Title', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the site title.', 'empt-lite' ),
		'section'  => 'title_tagline',
	) ) );		
		
	// Show site description
	$wp_customize->add_setting( 'empt_lite_hide_site_desc',	array(
		'default' => false,
		'transport'  => 'postMessage',
		'sanitize_callback' => 'empt_lite_sanitize_checkbox',
	) );  
	
	$wp_customize->add_control( new Empt_Lite_Toggle_Control( 
		$wp_customize, 'empt_lite_hide_site_desc', array(
		'label'    => esc_html__( 'Hide the Site Description', 'empt-lite' ),
		'description' => esc_html__( 'Show or hide the site tagline [description].', 'empt-lite' ),
		'section'  => 'title_tagline',
	) ) );

     // Site title colour
    $wp_customize->add_setting( 'empt_lite_sitetitle_color', array(
            'default'           => '#000',
			'transport' => 'postMessage',
            'sanitize_callback' => 'sanitize_hex_color'
     ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( 
		$wp_customize, 'empt_lite_sitetitle_color', array(
                'label'       => esc_html__( 'Site Title Colour', 'empt-lite' ),
                'description' => esc_html__( 'Sets the site title colour in the header area.', 'empt-lite' ),
                'section'     => 'title_tagline',             
     ) ) ); 

     // Site tagline colour
    $wp_customize->add_setting( 'empt_lite_sitetagline_color', array(
            'default'           => '#9a9a9a',
			'transport' => 'postMessage',
            'sanitize_callback' => 'sanitize_hex_color'
     ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( 
		$wp_customize, 'empt_lite_sitetagline_color', array(
                'label'       => esc_html__( 'Site Tagline Colour', 'empt-lite' ),
                'description' => esc_html__( 'Sets the site tagline [ description ] colour in the header area.', 'empt-lite' ),
                'section'     => 'title_tagline',             
     ) ) );

    // Site Title Font
    $wp_customize->add_setting( 'site_title_font', array(
            'default' => array(                                			
            'font-family' => 'Playfair Display',
            'variant'     => '700italic',
            ),
            'sanitize_callback' => array( 'Empt_Lite_Fonts', 'sanitize_typography' )
        ) );

	$wp_customize->add_control( new Empt_Lite_Typography_Control( $wp_customize, 'site_title_font', array(
			'label'       => esc_html__( 'Site Title Font', 'empt-lite' ),
			'description' => esc_html__( 'Site title and tagline font.', 'empt-lite' ),
			'section'     => 'title_tagline',
			'priority'    => 60, 
		) ) );
    
    // Site Title Font Size
    $wp_customize->add_setting( 'site_title_font_size', array(
            'default'           => 4,
			'transport'         => 'postMessage',
            'sanitize_callback' => 'empt_lite_sanitize_number_decimal',
        ) );
    
    $wp_customize->add_control( new Empt_Lite_Slider_Control( $wp_customize, 'site_title_font_size', array(
				'section'	  => 'title_tagline',
				'label'		  => esc_html__( 'Site Title Font Size', 'empt-lite' ),
				'description' => esc_html__( 'Change the font size of your site title.', 'empt-lite' ),
                'priority'    => 65,
                'choices'	  => array(
					'min' 	=> 1,
					'max' 	=> 10,
					'step'	=> 0.25,
			) ) )
		);
 
}
add_action( 'customize_register', 'empt_lite_customize_register' );
