/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	
		$head = $('head');

	// HexToRgb
		function hexToRgb( hex ) {
			var red = parseInt( hex.substring(1, 3), 16 ),
				green = parseInt( hex.substring(3, 5), 16 ),
				blue = parseInt( hex.substring(5, 7), 16 );
			return 'rgba( ' + red + ', ' + green + ', ' + blue + ' )';
		}

	// HexToRrgba
		function hexToRgba( hex, opacity ) {
			var red = parseInt( hex.substring(1, 3), 16 ),
				green = parseInt( hex.substring(3, 5), 16 ),
				blue = parseInt( hex.substring(5, 7), 16 );
			return 'rgba( ' + red + ', ' + green + ', ' + blue + ', ' + opacity + ' )';
		}
		
	// functions for our customer show or hide settings
	function hideElement( element ) {
		$( element ).css({
			clip: 'rect(1px, 1px, 1px, 1px)',
			position: 'absolute',
			width: '1px',
			height: '1px',
			overflow: 'hidden'
		});
	}

	function showElement( element ) {
		$( element ).css({
			clip: 'auto',
			position: 'relative',
			width: 'auto',
			height: 'auto',
			overflow: 'visible'
		});
	}
	
/* =======================
 Text based previews
======================= */
	
	// Site title.	
	wp.customize( 'blogname', function( value ) {
	  value.bind( function( newval ) {
		$( '#site-title' ).html( newval );
	  } );
	} );
	
	// Site description.	
	wp.customize( 'blogdescription', function( value ) {
	  value.bind( function( newval ) {
		$( '#site-description' ).html( newval );
	  } );
	} );


	// Default blog title text
	wp.customize( 'empt_lite_default_blog_title', function( value ) {
	  value.bind( function( newval ) {
		$( '.blog #page-title' ).html( newval );
	  } );
	} );

	// Default blog intro text
	wp.customize( 'empt_lite_default_blog_intro', function( value ) {
	  value.bind( function( newval ) {
		$( '.blog #page-intro' ).html( newval );
	  } );
	} );

	// More link text
	wp.customize( 'empt_lite_more_link_text', function( value ) {
	  value.bind( function( newval ) {
		$( '.more-link' ).html( newval );
	  } );
	} );	
	
	// Sticky post title
	wp.customize( 'empt_lite_related_posts_title', function( value ) {
	  value.bind( function( newval ) {
		$( '#related-posts-title' ).html( newval );
	  } );
	} );

	
	// Copyright
	wp.customize( 'empt_lite_copyright', function( value ) {
	  value.bind( function( newval ) {
		$( '#copyright-name' ).html( newval );
	  } );
	} );


/* =======================
 Font previews
 ======================= */


	// Site title font
	wp.customize( 'site_title_font', function( value ) {
		value.bind( function( to ) {
			var style = $('#site-title-font-css');
			style.remove();
			style = $( '<style type="text/css" id="site-title-font-css"> #site-title { font-family:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	// Site title size
	wp.customize( 'site_title_font_size', function( value ) {
		value.bind( function( to ) {
			var style = $('#site-title-size-css');
			style.remove();
			style = $( '<style type="text/css" id="site-title-size-css"> #site-title { font-size: calc(1rem + ' + to + 'vw) } </style>' ).appendTo( $head );
		} );
	} );


/* =======================
 Show or hide previews
======================= */
	
	// Show hide site title
	wp.customize( 'empt_lite_hide_site_title', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '#site-title' );
			} else {
				hideElement( '#site-title' );
			}
		} );
	} );
	
	// Show hide site tagline
	wp.customize( 'empt_lite_hide_site_desc', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '#site-description' );
			} else {
				hideElement( '#site-description' );
			}
		} );
	} );	
	
	// Show hide blog heading group
	wp.customize( 'empt_lite_hide_blog_heading', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.blog #page-header' );
			} else {
				hideElement( '.blog #page-header' );
			}
		} );
	} );


	// Show blog post meta info
	wp.customize( 'empt_lite_hide_blog_post_details', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.post-details' );
			} else {
				hideElement( '.post-details' );
			}
		} );
	} );



	// Show hide blog author
	wp.customize( 'empt_lite_hide_blog_author_name', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.byline' );
			} else {
				hideElement( '.byline' );
			}
		} );
	} );

	// Show hide blog featured label
	wp.customize( 'empt_lite_hide_blog_featured_label', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.featured-label' );
			} else {
				hideElement( '.featured-label' );
			}
		} );
	} );
	
	// Show hide blog date
	wp.customize( 'empt_lite_hide_blog_date', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.publish-date' );
			} else {
				hideElement( '.publish-date' );
			}
		} );
	} );

	// Show hide blog update
	wp.customize( 'empt_lite_hide_blog_update', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.posted-update' );
			} else {
				hideElement( '.posted-update' );
			}
		} );
	} );
	
	// Show hide blog format
	wp.customize( 'empt_lite_hide_blog_format', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.post-format' );
			} else {
				hideElement( '.post-format' );
			}
		} );
	} );

	// Show hide blog comment link
	wp.customize( 'empt_lite_hide_blog_comments_link', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.comments-link' );
			} else {
				hideElement( '.comments-link' );
			}
		} );
	} );


	// Show hide blog edit link
	wp.customize( 'empt_lite_hide_edit', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.edit-link' );
			} else {
				hideElement( '.edit-link' );
			}
		} );
	} );

	// Show hide blog category 
	wp.customize( 'empt_lite_hide_blog_categories', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.post-category' );
			} else {
				hideElement( '.post-category' );
			}
		} );
	} );

	// Show hide blog tags 
	wp.customize( 'empt_lite_hide_blog_tags_list', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.tags-links' );
			} else {
				hideElement( '.tags-links' );
			}
		} );
	} );
	
	// Show hide readmore
	wp.customize( 'empt_lite_hide_excerpt_more_link', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.more-link-wrapper' );
			} else {
				hideElement( '.more-link-wrapper' );
			}
		} );
	} );

	// Show comment author role
	wp.customize( 'empt_lite_hide_post_comment_author_role', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.by-post-author' );
			} else {
				hideElement( '.by-post-author' );
			}
		} );
	} );

	// Show hide post tags 
	wp.customize( 'empt_lite_show_hide_post_tags', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '#post-tags' );
			} else {
				hideElement( '#post-tags' );
			}
		} );
	} );
	
	
	// Show blog author
	wp.customize( 'empt_lite_hide_blog_author_name', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.post-author-avatar' );
				showElement( '.post-author' );
			} else {
				hideElement( '.post-author-avatar' );
				hideElement( '.post-author' );
			}
		} );
	} );		
	
	// Show hide post featured image
	wp.customize( 'empt_lite_show_hide_post_image', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.single .post-thumbnail' );
			} else {
			hideElement( '.single .post-thumbnail' );
			}
		} );
	} );	
	
	// Show post author
	wp.customize( 'empt_lite_show_post_author', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.byline' );
			} else {
				hideElement( '.byline' );
			}
		} );
	} );	
	
	// Show hide post date
	wp.customize( 'empt_lite_hide_post_date', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.publish-date' );
			} else {
				hideElement( '.publish-date' );
			}
		} );
	} );	
	
	// Show hide post categories
	wp.customize( 'empt_lite_hide_category', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.cat-links' );
			} else {
				hideElement( '.cat-links' );
			}
		} );
	} );	

	// Show hide post tags
	wp.customize( 'empt_lite_hide_post_tags', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.tags-list' );
			} else {
				hideElement( '.tags-list' );
			}
		} );
	} );
	
	// Show hide author bio
	wp.customize( 'empt_lite_hide_author_bio', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.author-info' );
			} else {
				hideElement( '.author-info' );
			}
		} );
	} );

	// Show hide post related
	wp.customize( 'empt_lite_hide_related', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '#related-posts' );
			} else {
				hideElement( '#related-posts' );
			}
		} );
	} );
	
	// Show hide post nav
	wp.customize( 'empt_lite_hide_post_nav', function( value ) {
		value.bind( function( newval ) {
			if ( false === newval ) {
				showElement( '.post-navigation' );
			} else {
				hideElement( '.post-navigation' );
			}
		} );
	} );

/* =======================
 Colours
======================= */

	/* page loader */
	wp.customize( 'empt_lite_loader_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-loader-colour-css');
			
			style.remove();
			style = $( '<style type="text/css" id="custom-loader-colour-css"> .pace .pace-progress { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );


	/* site title */
	wp.customize( 'empt_lite_sitetitle_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-sitetitle-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-sitetitle-colour-css"> #site-title a, #site-title a:visited { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* site tagline */
	wp.customize( 'empt_lite_sitetagline_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-sitetagline-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-sitetagline-colour-css"> #site-description { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );
	
	/* site footer background */
	wp.customize( 'empt_lite_footer_bg_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-bg-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-bg-css"> #footer-wrapper { background:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );	

	/* body text */
	wp.customize( 'empt_lite_body_text_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-body-text-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-body-text-css"> body { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* archive prefix colour */
	wp.customize( 'empt_lite_archive_prefix_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-archive-prefix-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-archive-prefix-colour-css"> .archive-prefix.color { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );
	
	/* headings */
	wp.customize( 'empt_lite_heading_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-heading-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-heading-colour-css"> h1, h2, h3, h4, h5, h6, h1 a, h2 a, h3 a, h4 a, h5 a, h6 a { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* page intro */
	wp.customize( 'empt_lite_page_intro_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-page-intro-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-page-intro-colour-css"> #page-intro { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* links */
	wp.customize( 'empt_lite_links_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-links-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-links-colour-css"> a { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* link active hover */
	wp.customize( 'empt_lite_link_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-link-hover-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-link-hover-colour-css"> a:visited, a:focus, a:hover { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* blockquote icon */
	wp.customize( 'empt_lite_blockquote_icon_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-blockquote-icon-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-blockquote-icon-colour-css"> blockquote:before { color: ' + hexToRgb( to ) + '; opacity: 0.4; } </style>' ).appendTo( $head );
		} );
	} );

	/* footer widget title */
	wp.customize( 'empt_lite_footer_widget_title_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-widget-title-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-widget-title-colour-css"> #footer-wrapper .widget-title { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* footer widget title line*/
	wp.customize( 'empt_lite_footer_widget_title_line', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-widget-title-line-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-widget-title-line-colour-css"> #footer-wrapper .widget-title::after { background:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );
	
	/* footer widget text */
	wp.customize( 'empt_lite_footer_widget_text_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-text-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-text-colour-css"> #footer-wrapper { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* footer widget links */
	wp.customize( 'empt_lite_footer_widget_link_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-link-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-link-colour-css"> #footer-wrapper a, #footer-wrapper a:visited { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* footer widget link hover */
	wp.customize( 'empt_lite_footer_widget_link_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-link-hover-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-link-hover-colour-css"> #footer-wrapper a:focus, #footer-wrapper a:hover, #footer-wrapper #empt-recent-comments .comment-link:hover { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* footer widget list lines */
	wp.customize( 'empt_lite_footer_widget_list_line_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-list-line-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-list-line-colour-css"> #footer-sidebars .widget > ul > li { border-color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	/* footer tagcloud */
	wp.customize( 'empt_lite_footer_widget_tags_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-tagcloud-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-tagcloud-colour-css"> #footer-sidebars .tag-cloud-link { border-color:' + to + '; color:' + to + ' !important; } </style>' ).appendTo( $head );
		} );
	} );

	/* footer tagcloud hover */
	wp.customize( 'empt_lite_footer_widget_tags_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-tagcloud-hover-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-tagcloud-hover-colour-css"> #footer-sidebars .tag-cloud-link:hover { border-color:' + to + '; color:' + to + ' !important; } </style>' ).appendTo( $head );
		} );
	} );

	/* footer line */
	wp.customize( 'empt_lite_footer_line_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-line-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-line-colour-css"> #footer  { border-color:' + to + '; } </style>' ).appendTo( $head );
		} );
	} );

	/* footer text */
	wp.customize( 'empt_lite_footer_text_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-text-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-text-colour-css"> #footer  { color:' + to + '; } </style>' ).appendTo( $head );
		} );
	} );

	/* footer menu */
	wp.customize( 'empt_lite_footer_menu_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-menu-colour-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-footer-menu-colour-css"> #footer-menu a  { color:' + to + '; } </style>' ).appendTo( $head );
		} );
	} );

	/* footer menu hover */
	wp.customize( 'empt_lite_footer_menu_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-menu-hover-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-footer-menu-hover-colour-css"> #footer-menu a:hover  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* footer menu hover */
	wp.customize( 'empt_lite_footer_menu_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-menu-hover-line-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-footer-menu-hover-line-colour-css"> #footer-nav a::before, #footer-nav a::after  { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* social */
	wp.customize( 'empt_lite_social_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-social-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-social-colour-css"> #footer-social a  { border-color:' + to + '; color:' + to + ';} </style>' ).
			appendTo( $head );
		} );
	} );

	/* social hover */
	wp.customize( 'empt_lite_social_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-social-hover-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-social-hover-colour-css"> #footer-social a:hover  { border-color:' + to + '; color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* post details */
	wp.customize( 'empt_lite_post_details', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-post-details-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-post-details-colour-css"> .post-details  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* post details linked */
	wp.customize( 'empt_lite_post_details_linked', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-post-details-link-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-post-details-link-colour-css"> .post-details a, .post-details a:visited  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* post details linked */
	wp.customize( 'empt_lite_post_blog_details_linked', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-details-blog-meta-link-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-details-blog-meta-link-colour-css"> .blog-details .post-details a, .blog-details .post-details a:visited  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* post details hover */
	wp.customize( 'empt_lite_post_details_hover', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-post-details-hover-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-post-details-hover-colour-css"> .post-details a:hover, .blog-details .post-details a:hover, .blog-details .post-details a:hover  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* post details hover line */
	wp.customize( 'empt_lite_post_details_hover', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-post-details-hover-line-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-post-details-hover-line-colour-css"> .post-details a::before, .post-details a::after, .blog-details .post-details a::before, .blog-details .post-details a::after  { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* blog details style - vert line */
	wp.customize( 'empt_lite_blog_detail_style_separator', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-blog-details-line-colour-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-blog-details-line-colour-css"> .blog-details .post-details  { border-color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );


	/* title bottom lines */
	wp.customize( 'empt_lite_title_bottom_line', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-widget-title-line-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-widget-title-line-css"> .entry-title:after, .widget-title:after { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );
	
	/* blog gallery style overlay */
	wp.customize( 'empt_lite_blog_gallery_overlay', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-blog-gallery-overlay-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-blog-gallery-overlay-css"> .blog-gallery .grid-item .content-overlay  { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* blog gallery style ttle */
	wp.customize( 'empt_lite_blog_gallery_title', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-blog-gallery-title-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-blog-gallery-title-css"> .blog-gallery .entry-title a, .blog-gallery .entry-title a:visited  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* blog gallery style readmore */
	wp.customize( 'empt_lite_blog_gallery_readmore', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-blog-gallery-readmore-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-blog-gallery-readmore-css"> .blog-gallery .more-link, .blog-gallery .more-link:visited  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* blog gallery style readmore hover */
	wp.customize( 'empt_lite_blog_gallery_readmore_hover', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-blog-gallery-readmore-hover-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-blog-gallery-readmore-hover-css"> .blog-gallery .more-link:focus, .blog-gallery .more-link:hover  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* blog gallery style readmore hover */
	wp.customize( 'empt_lite_blog_gallery_readmore_hover', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-blog-gallery-readmore-hover-line-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-blog-gallery-readmore-hover-line-colour-css"> .blog-gallery .more-link::before, .blog-gallery .more-link::after  { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* about widget bg */
	wp.customize( 'empt_lite_about_widget_bg', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-about-widget-bg-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-about-widget-bg-css"> .empt-widget-about  { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* about widget text */
	wp.customize( 'empt_lite_about_widget_text', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-about-widget-text-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-about-widget-text-css"> .empt-widget-about  { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* about widget title */
	wp.customize( 'empt_lite_about_widget_title', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-about-widget-title-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-about-widget-title-css"> .empt-widget-about .about-me-name { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* widget list line */
	wp.customize( 'empt_lite_widget_list_lines', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-widget-list-line-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-widget-list-line-css"> .widget > ul > li, .widget_nav_menu li ul { border-color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* button bg */
	wp.customize( 'empt_lite_button_bg', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-button-bg-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-button-bg-css"> .button, button, input[type="button"], input[type="reset"], input[type="submit"] { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* button text */
	wp.customize( 'empt_lite_button_text', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-button-text-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-button-text-css"> .button, button, input[type="button"], input[type="reset"], input[type="submit"] { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* button hover bg */
	wp.customize( 'empt_lite_button_hover_bg', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-button-hover-bg-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-button-hover-bg-css"> .button:active,.button:focus,.button:hover,button:active,button:focus,button:hover,input[type="button"]:active,input[type="button"]:focus,input[type="button"]:hover,input[type="reset"]:active,input[type="reset"]:focus,input[type="reset"]:hover,input[type="submit"]:active,input[type="submit"]:focus,input[type="submit"]:hover { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* button hover text */
	wp.customize( 'empt_lite_button_hover_text', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-button-hover-text-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-button-hover-text-css"> .button:active, .button:focus, .button:hover,button:active, button:focus,button:hover, input[type="button"]:active,input[type="button"]:focus, input[type="button"]:hover, input[type="reset"]:active, input[type="reset"]:focus, input[type="reset"]:hover, input[type="submit"]:active, input[type="submit"]:focus, input[type="submit"]:hover { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	
	/* footer button bg */
	wp.customize( 'empt_lite_footer_button_bg', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-button-bg-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-footer-button-bg-css"> #footer-wrapper .button, #footer-wrapper .button:visited, #footer-wrapper button, #footer-wrapper input[type="button"], #footer-wrapper input[type="reset"], #footer-wrapper input[type="submit"], #footer-wrapper button:visited, #footer-wrapper input[type="button"]:visited, #footer-wrapper input[type="reset"]:visited, #footer-wrapper input[type="submit"]:visited { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );	
	
	/* footer button text */
	wp.customize( 'empt_lite_footer_button_text', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-button-text-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-footer-button-text-css"> #footer-wrapper .button, #footer-wrapper .button:visited, #footer-wrapper button, #footer-wrapper input[type="button"], #footer-wrapper input[type="reset"], #footer-wrapper input[type="submit"], #footer-wrapper button:visited, #footer-wrapper input[type="button"]:visited, #footer-wrapper input[type="reset"]:visited, #footer-wrapper input[type="submit"]:visited { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );		
	
	/* footer button hover bg */
	wp.customize( 'empt_lite_footer_button_hover_bg', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-button-hover-bg-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-footer-button-hover-bg-css"> #footer-wrapper .button:focus, #footer-wrapper .button:hover, #footer-wrapper button:active, #footer-wrapper button:focus, #footer-wrapper button:hover, #footer-wrapper input[type="button"]:active, #footer-wrapper input[type="button"]:focus, #footer-wrapper input[type="button"]:hover, #footer-wrapper input[type="reset"]:active, #footer-wrapper input[type="reset"]:focus, #footer-wrapper input[type="reset"]:hover, #footer-wrapper input[type="submit"]:active, #footer-wrapper input[type="submit"]:focus, #footer-wrapper input[type="submit"]:hover { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );		
	
	/* footer button hover text */
	wp.customize( 'empt_lite_footer_button_hover_text', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-footer-button-hover-text-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-footer-button-hover-text-css"> #footer-wrapper .button:focus, #footer-wrapper .button:hover, #footer-wrapper button:active, #footer-wrapper button:focus, #footer-wrapper button:hover, #footer-wrapper input[type="button"]:active, #footer-wrapper input[type="button"]:focus, #footer-wrapper input[type="button"]:hover, #footer-wrapper input[type="reset"]:active, #footer-wrapper input[type="reset"]:focus, #footer-wrapper input[type="reset"]:hover, #footer-wrapper input[type="submit"]:active, #footer-wrapper input[type="submit"]:focus, #footer-wrapper input[type="submit"]:hover { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );	
	

	/* form input field bg */
	wp.customize( 'empt_lite_input_field_bg', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-input-bg-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-input-bg-css"> input[type="text"], input[type="email"], input[type="url"], input[type="password"], input[type="search"], input[type="number"], input[type="tel"], input[type="range"], input[type="date"], input[type="month"], input[type="week"], input[type="time"], input[type="datetime"], input[type="datetime-local"], input[type="color"], textarea { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* form input field border */
	wp.customize( 'empt_lite_input_field_border', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-input-border-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-input-border-css"> input[type="text"], input[type="email"], input[type="url"], input[type="password"], input[type="search"], input[type="number"], input[type="tel"], input[type="range"], input[type="date"], input[type="month"], input[type="week"], input[type="time"], input[type="datetime"], input[type="datetime-local"], input[type="color"], textarea { border-color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* form input field text */
	wp.customize( 'empt_lite_input_field_text', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-input-text-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-input-text-css"> input[type="text"], input[type="email"], input[type="url"], input[type="password"], input[type="search"], input[type="number"], input[type="tel"], input[type="range"], input[type="date"], input[type="month"], input[type="week"], input[type="time"], input[type="datetime"], input[type="datetime-local"], input[type="color"], textarea { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* form input field hover border */
	wp.customize( 'empt_lite_input_field_hover_border', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-input-hover-border-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-input-hover-border-css"> input[type="text"]:focus, input[type="email"]:focus, input[type="url"]:focus, input[type="password"]:focus, input[type="search"]:focus, input[type="number"]:focus, input[type="tel"]:focus, input[type="range"]:focus, input[type="date"]:focus, input[type="month"]:focus, input[type="week"]:focus, input[type="time"]:focus, input[type="datetime"]:focus, input[type="datetime-local"]:focus, input[type="color"]:focus, textarea:focus, input[type="text"]:hover, input[type="email"]:hover, input[type="url"]:hover, input[type="password"]:hover, input[type="search"]:hover, input[type="number"]:hover, input[type="tel"]:hover, input[type="range"]:hover, input[type="date"]:hover, input[type="month"]:hover, input[type="week"]:hover, input[type="time"]:hover, input[type="datetime"]:hover, input[type="datetime-local"]:hover, input[type="color"]:hover, textarea:hover { border-color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* form input field placeholder */
	wp.customize( 'empt_lite_input_placeholder', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-input-placeholder-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-input-placeholder-css"> ::-webkit-input-placeholder { color:' + to + '; } :-ms-input-placeholder { color:' + to + '; } ::-moz-placeholder { color:' + to + '; } ::placeholder { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* pagination */
	wp.customize( 'empt_lite_pagination_link', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-pagination-link-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-pagination-link-css"> .pagination a, .pagination a:visited, .nav-links a { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* selection bg */
	wp.customize( 'empt_lite_selection_bg_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-selection-bg-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-selection-bg-css"> ::selection { background:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* selection text */
	wp.customize( 'empt_lite_selection_text_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-selection-text-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-selection-text-css"> ::selection { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* main menu link */
	wp.customize( 'empt_lite_mainmenu_link', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-mainmenu-link-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-mainmenu-link-css"> .main-navigation a, .main-navigation a:visited, .main-navigation .home.current-menu-item a { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* main menu hover link */
	wp.customize( 'empt_lite_mainmenu_hover_link', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-mainmenu-hover-link-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-mainmenu-hover-link-css"> .main-navigation .home.current-menu-item a:hover, .main-navigation a:focus, .main-navigation a:hover, .main-navigation .current-menu-item > a, .main-navigation .current-menu-ancestor > a { color:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );

	/* main menu arrow */
	wp.customize( 'empt_lite_mainmenu_arrow', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-mainmenu-arrow-css');
			style.remove();
			style = $( '<style type="text/css" id="custom-mainmenu-arrow-css"> .main-navigation ul .icon { fill:' + to + '; } </style>' ).
			appendTo( $head );
		} );
	} );



	
} )( jQuery );
