<?php
/**
* Functions which enhance the theme by hooking into WordPress
* @package Purified
*/	


/*	-----------------------------------------------------------------------------------------------
	BODY CLASSES
	Conditional addition of classes to the body element
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_body_classes' ) ) :
	function empt_lite_body_classes( $classes ) {


		global $post;
		$post_type = isset( $post ) ? $post->post_type : false;

		// Adds a class of hfeed to non-singular pages.
		if ( ! is_singular() ) {
			$classes[] = 'hfeed';
		}
		
		// Blog layout
		$empt_lite_blog_layout = esc_attr(get_theme_mod( 'empt_lite_blog_layout', 'classic' ) );	
		if( $empt_lite_blog_layout !== 'default' && ! is_singular() ) {
			$classes[] = 'blog-' . $empt_lite_blog_layout;
		}		
		
		// Single layout
		$empt_lite_single_layout = esc_attr(get_theme_mod( 'empt_lite_single_layout', 'right' ) );	
		if( $empt_lite_single_layout !== 'default' && is_single() ) {
			$classes[] = 'single-' . $empt_lite_single_layout;
			}	

		
		// Check whether the current page is the default page template but not a post single
		if(basename(get_page_template()) === 'page.php' && !is_single() && !is_home() && !is_archive() && !is_page_template( array( 'templates/template-left.php', 'templates/template-right.php'))) {
		$classes[] = 'default-page';
		}
		
		// Check whether the current page is the left column template
		if ( is_page_template( array( 'templates/template-left.php' ) ) ) {
			$classes[] = 'template-left';
		}

		// Check whether the current page is the right column template
		if ( is_page_template( array( 'templates/template-right.php' ) ) ) {
			$classes[] = 'template-right';
		}
		
		// Check whether we're in the customizer preview
		if ( is_customize_preview() ) {
			$classes[] = 'customizer-preview';
		}

		// Check whether we're in the customizer preview
		if ( ! has_post_thumbnail() ) {
			$classes[] = 'no-thumbnail';
		}
		
		return $classes;

	}
	endif;	
add_action( 'body_class', 'empt_lite_body_classes' );


/*	-----------------------------------------------------------------------------------------------
	ADD EXCERPT SUPPORT TO PAGES
	Allows the addition of an excerpt to your pages
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_add_excerpt_support_to_pages' ) ) :
	function empt_lite_add_excerpt_support_to_pages() {

		add_post_type_support( 'page', 'excerpt' );
		
	}
	add_action( 'init', 'empt_lite_add_excerpt_support_to_pages' );
endif;	
	

 /*	-----------------------------------------------------------------------------------------------
	ARCHIVE TITLE PREFIX
	Filters the archive title and styles the word before the first colon.
--------------------------------------------------------------------------------------------------- */
function empt_lite_prefix_archive_title( $title ) {

	$regex = apply_filters(
		'empt_lite_prefix_the_archive_title_regex',
		array(
			'pattern'     => '/(\A[^\:]+\:)/',
			'replacement' => '<span class="archive-prefix color">$1</span>',
		)
	);

	if ( empty( $regex ) ) {
		return $title;
	}
	return preg_replace( $regex['pattern'], $regex['replacement'], $title );
}

add_filter( 'get_the_archive_title', 'empt_lite_prefix_archive_title' );

/*	-----------------------------------------------------------------------------------------------
	FILTER ARCHIVE TITLE
	Manage the archive titles
--------------------------------------------------------------------------------------------------- */

if( ! function_exists( 'empt_lite_get_the_archive_title' ) ) :
function empt_lite_get_the_archive_title( $title ){
    
    $ed_prefix = get_theme_mod( 'empt_lite_prefix_archive', false );
    
    // Use the blog page title on home
		$blog_page_id = get_option( 'page_for_posts' );
		if ( ! is_front_page() && is_home() && $blog_page_id && get_the_title( $blog_page_id ) ) {
			$title = get_the_title( $blog_page_id );
			
    }elseif( $ed_prefix ){
        if( is_category() ){
            $title = single_cat_title( '', false );
        }elseif ( is_tag() ){
            $title = single_tag_title( '', false );
        }elseif( is_author() ){
            $title = '<span class="vcard">' . get_the_author() . '</span>';
        }elseif ( is_year() ) {
            $title = get_the_date( __( 'Y', 'empt-lite' ) );
        }elseif ( is_month() ) {
            $title = get_the_date( __( 'F Y', 'empt-lite' ) );
        }elseif ( is_day() ) {
            $title = get_the_date( __( 'F j, Y', 'empt-lite' ) );
        }elseif ( is_post_type_archive() && ! is_post_type_archive( 'product' ) ) {
            $title = post_type_archive_title( '', false );       
        }elseif ( is_tax() ) {
            $tax = get_taxonomy( get_queried_object()->taxonomy );
            $title = single_term_title( '', false );
        }
    }    
    return $title;
}
endif;
add_filter( 'get_the_archive_title', 'empt_lite_get_the_archive_title' );

/*	-----------------------------------------------------------------------------------------------
	FILTER ARCHIVE DESCRIPTION
	The initial description
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_get_the_archive_description' ) ) :
	function empt_lite_get_the_archive_description( $description ) {

		// Use the blog page manual excerpt on home
		$blog_page_id = get_option( 'page_for_posts' );
		if ( is_home() && $blog_page_id && has_excerpt( $blog_page_id ) ) {
			$description = get_the_excerpt( $blog_page_id );
		}

		return $description;
		
	}
	add_filter( 'get_the_archive_description', 'empt_lite_get_the_archive_description' );
endif;	


/*	-----------------------------------------------------------------------------------------------
	IS COMMENT BY POST AUTHOR?
	Check if the specified comment is written by the author.
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_is_comment_by_post_author' ) ) :
	function empt_lite_is_comment_by_post_author( $comment = null ) {

		if ( is_object( $comment ) && $comment->user_id > 0 ) {
			$user = get_userdata( $comment->user_id );
			$post = get_post( $comment->comment_post_ID );
			if ( ! empty( $user ) && ! empty( $post ) ) {
				return $comment->user_id === $post->post_author;
			}
		}
		return false;

	}
endif;	


/* -----------------------------------------------------------------------------------------------
	ADD A SUB NAV TOGGLE TO THE MAIN MENU
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_add_sub_toggles_to_main_menu' ) ) :
	function empt_lite_add_sub_toggles_to_main_menu( $args, $item, $depth ) {

		// Add sub menu toggles to the main menu with toggles
		if ( $args->theme_location == 'main-menu' && isset( $args->show_toggles ) ) {

			// Wrap the menu item link contents in a div, used for positioning
			$args->before = '<div class="ancestor-wrapper">';
			$args->after = '';

			// Add a toggle to items with children
			if ( in_array( 'menu-item-has-children', $item->classes ) ) {

				$toggle_target_string = '.menu-modal .menu-item-' . $item->ID . ' > .sub-menu';

				// Add the sub menu toggle
				$args->after .= '<button class="toggle sub-menu-toggle fill-children-current-color" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250"><span class="screen-reader-text">' . __( 'Show sub menu', 'empt-lite' ) . '</span>' . empt_lite_get_theme_svg( 'chevron-down' ) . '</button>';

			}

			// Close the wrapper
			$args->after .= '</div><!-- .ancestor-wrapper -->';

		// Add sub menu icons to the main menu without toggles (the fallback menu)
		} elseif ( $args->theme_location == 'main-menu' ) {
			if ( in_array( 'menu-item-has-children', $item->classes ) ) {
				$args->before = '<div class="link-icon-wrapper fill-children-current-color">';
				$args->after = empt_lite_get_theme_svg( 'chevron-down' ) . '</div>';
			} else {
				$args->before = '';
				$args->after = '';
			}
		}

		return $args;

	}
	add_filter( 'nav_menu_item_args', 'empt_lite_add_sub_toggles_to_main_menu', 10, 3 );
endif;

/*-----------------------------------------------------------------------------------------------
	FILTER THE EXCERPT LENGTH
	Modify the length of automated excerpts to better fit the Empt previews
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_excerpt_length' ) ) {
	function empt_lite_excerpt_length( $length ) {

		if ( is_admin() ) {
			return $length;
		}

		// Get excerpt length from customizer.
		$excerpt_length = esc_attr(get_theme_mod( 'empt_lite_custom_excerpt_length', '35' ) );
		// Return excerpt text.
			return $excerpt_length; // Number of words.
	}
}
add_filter( 'excerpt_length', 'empt_lite_excerpt_length', 999 );



/*-----------------------------------------------------------------------------------------------
	FILTER THE EXCERPT SUFFIX
	Replaces the default [...] with a &hellip; (three dots)
--------------------------------------------------------------------------------------------------- */

if ( ! function_exists( 'empt_lite_excerpt_more' ) ) :
	function empt_lite_excerpt_more() {
		return '&hellip;';
	}
	add_filter( 'excerpt_more', 'empt_lite_excerpt_more' );
endif;


/*	-----------------------------------------------------------------------------------------------
	STANDALONE MORE LINK
	Display a standalone link for special excerpts
--------------------------------------------------------------------------------------------------- */
if ( ! function_exists( 'empt_lite_read_more_link' ) ) :
	function empt_lite_read_more_link() {
	$empt_lite_more_link_text = esc_html( get_theme_mod( 'empt_lite_more_link_text', __('Read More', 'empt-lite') ) );
		echo '<p class="more-link-wrapper"><a class="more-link" href="'. esc_url(get_permalink()) . '">' . wp_kses_post( $empt_lite_more_link_text ) . '</a></p>';
	}
endif;


/*	-----------------------------------------------------------------------------------------------
	MOVE READ MORE LINK OUTSIDE OF PARAGRAPHS
	This moves the more-link outside of the inline paragraph of blog summaries
	-------------------------------------------------------------------------------------------------- */
if ( ! function_exists( 'empt_lite_move_more_link' ) ) :
	function empt_lite_move_more_link() {
		$empt_lite_more_link_text = esc_html( get_theme_mod( 'empt_lite_more_link_text', __('Read More', 'empt-lite') ) );

	//if ( false == esc_attr(get_theme_mod( 'empt_lite_hide_blog_readmore', false ) ) ) {
			return '<p><a class="more-link" href="'. esc_url(get_permalink()) . '">' . wp_kses_post( $empt_lite_more_link_text ) . '</a></p>';
		//}
	}
add_filter( 'the_content_more_link', 'empt_lite_move_more_link' );
endif;


    /**
     * Fire the wp_body_open action.
     *
     * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
     *
     */
if ( ! function_exists( 'wp_body_open' ) ) :
    function wp_body_open() {
       // Triggered after the opening <body> tag.
        do_action( 'wp_body_open' );
    }
endif;

/**
 * Return Web safe font and google font
*/
if( ! function_exists( 'empt_lite_get_all_fonts' ) ) :
function empt_lite_get_all_fonts(){
    $google = array();        
    $standard = array(
		'georgia-serif'       => __( 'Georgia', 'empt-lite' ),
        'palatino-serif'      => __( 'Palatino Linotype, Book Antiqua, Palatino', 'empt-lite' ),
        'times-serif'         => __( 'Times New Roman, Times', 'empt-lite' ),
        'arial-helvetica'     => __( 'Arial, Helvetica', 'empt-lite' ),
        'arial-gadget'        => __( 'Arial Black, Gadget', 'empt-lite' ),
		'comic-cursive'       => __( 'Comic Sans MS, cursive', 'empt-lite' ),
		'impact-charcoal'     => __( 'Impact, Charcoal', 'empt-lite' ),
        'lucida'              => __( 'Lucida Sans Unicode, Lucida Grande', 'empt-lite' ),
        'tahoma-geneva'       => __( 'Tahoma, Geneva', 'empt-lite' ),
		'trebuchet-helvetica' => __( 'Trebuchet MS, Helvetica', 'empt-lite' ),
		'verdana-geneva'      => __( 'Verdana, Geneva', 'empt-lite' ),
        'courier'             => __( 'Courier New, Courier', 'empt-lite' ),
        'lucida-monaco'       => __( 'Lucida Console, Monaco', 'empt-lite' ),
	);
    
    $fonts = include wp_normalize_path( get_template_directory() . '/inc/custom-controls/typography/webfonts.php' );
    
    foreach( $fonts['items'] as $font ){
        $google[$font['family']] = $font['family'];
    }
    $all_fonts = array_merge( $standard, $google );
    return $all_fonts; 
}
endif;